@@ -24,7 +24,6 @@ from aiohttp import ClientResponseError
 from aiohttp import ServerDisconnectedError
 from pydantic.dataclasses import dataclass
 from tortoise import fields
-from tortoise.transactions import get_connection
 
 from dipdup.config import DEFAULT_POSTGRES_SCHEMA
 from dipdup.config import HasuraConfig
@@ -36,6 +35,7 @@ from dipdup.http import HTTPGateway
 from dipdup.models import Schema
 from dipdup.utils import iter_files
 from dipdup.utils import pascal_to_snake
+from dipdup.utils.database import get_connection
 from dipdup.utils.database import iter_models
 
 _get_fields_query = '''
@@ -227,10 +227,11 @@ class HasuraGateway(HTTPGateway):
         await self._hasura_request(endpoint, json)
 
     async def _get_views(self) -> List[str]:
+        conn = get_connection()
         views = [
             row[0]
             for row in (
-                await get_connection(None).execute_query(
+                await conn.execute_query(
                     f"SELECT table_name FROM information_schema.views WHERE table_schema = '{self._database_config.schema_name}' UNION "
                     f"SELECT matviewname as table_name FROM pg_matviews WHERE schemaname = '{self._database_config.schema_name}'"
                 )
@@ -377,7 +378,7 @@ class HasuraGateway(HTTPGateway):
         for field_json in fields_json:
             # NOTE: Exclude autogenerated aggregate and pk fields
             ignore_postfixes = ('_aggregate', '_by_pk', 'Aggregate', 'ByPk')
-            if any(map(lambda postfix: field_json['name'].endswith(postfix), ignore_postfixes)):
+            if any(field_json['name'].endswith(p) for p in ignore_postfixes):
                 continue
 
             # NOTE: Exclude relations. Not reliable enough but ok for now.
@@ -438,7 +439,7 @@ class HasuraGateway(HTTPGateway):
             name = humps.camelize(name)
             filter = humps.camelize(filter)
             table = humps.camelize(table)
-            map(lambda f: f.camelize(), fields)
+            fields = [f.camelize() for f in fields]
 
         try:
             filter_field = next(f for f in fields if f.name == filter)
